@@ -74,6 +74,7 @@ class BaseAlertsResource(ABC):
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
+        page: Optional[int] = None,
     ) -> List[Alert]:
         response = await self._get_page(
             user_uuid=user_uuid,
@@ -81,9 +82,10 @@ class BaseAlertsResource(ABC):
             utc_starttime=utc_starttime,
             utc_endtime=utc_endtime,
             labels=labels,
+            page=page or 1,
         )
         max_pages = response.meta.max_pages
-        if max_pages > 1:
+        if not page and max_pages > 1:
             coroutines = [
                 self._get_page(
                     user_uuid=user_uuid,
@@ -112,6 +114,7 @@ class AsyncAlertsResource(BaseAlertsResource):
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
+        page: Optional[int] = None,
     ) -> List[Alert]:
         return await self._get(
             user_uuid=user_uuid,
@@ -119,6 +122,7 @@ class AsyncAlertsResource(BaseAlertsResource):
             utc_starttime=utc_starttime,
             utc_endtime=utc_endtime,
             labels=labels,
+            page=page,
         )
 
 
@@ -131,6 +135,7 @@ class SyncAlertsResource(BaseAlertsResource):
         utc_starttime: Optional[datetime] = None,
         utc_endtime: Optional[datetime] = None,
         labels: Optional[Sequence[str]] = None,
+        page: Optional[int] = None,
     ) -> List[Alert]:
         return self._client.run(
             self._get(
@@ -139,5 +144,6 @@ class SyncAlertsResource(BaseAlertsResource):
                 utc_starttime=utc_starttime,
                 utc_endtime=utc_endtime,
                 labels=labels,
+                page=page,
             )
         )
